﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WmsServerEdition;
using System.Drawing;
using System.IO;
using System.Collections.ObjectModel;

namespace WmsPlugins
{
    public class DynamicallyCreateLayers:WmsLayerPlugin
    {
        protected override MapConfiguration GetMapConfigurationCore(string style, string crs)
        {
            return new MapConfiguration();
        }

        protected override Bitmap GetMapCore(GetMapRequest getMapRequest, MapConfiguration cachedMapConfiguration, System.Web.HttpContext context)
        {
            //this is the parameter which you request from the client. You can split it as you query conditions.
            string customParameter = getMapRequest.CustomParameter;

            if (cachedMapConfiguration.Layers.Count == 0 && !string.IsNullOrEmpty(customParameter))
            {
                // Get the directory to the sample data
                string worldLayerFilePath = Directory.GetParent(Directory.GetParent(AppDomain.CurrentDomain.BaseDirectory).FullName).FullName + Path.DirectorySeparatorChar + "SampleData" + Path.DirectorySeparatorChar + customParameter;

                // Create the world layer from a shapefile and add a style to it
                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(worldLayerFilePath);
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                // Create a MapConfiguration and add the layer to it
                cachedMapConfiguration = new MapConfiguration();
                cachedMapConfiguration.Layers.Add("ASelectedLayer", worldLayer);
            }
            return base.GetMapCore(getMapRequest, cachedMapConfiguration, context);
        }

        protected override string GetNameCore()
        {
            return "Dynamically Create Layers";
        }

        protected override Collection<string> GetProjectionsCore()
        {
            return new Collection<string> { "EPSG:4326" };
        }

        protected override RectangleShape GetBoundingBoxCore(string crs)
        {
            return new RectangleShape(-126.826171875, 57.104766845702, -70.83984375, 18.960235595702);
        }

    }
}
